@@ -245,80 +245,82 @@
 				$(map.children(".roundabout-map-overlay")[0]).append('<div class="roundabout-map-compass">&nbsp;</div>');
 				map = $(map.children(".roundabout-map-container")[0]);
 				for (x in options.maps) {
-					map.append('<div id="roundabout-map-' + x + '"></div>');
-					var curmap = $(map.children("#roundabout-map-" + x)[0]);
-					curmap.append('<img id="roundabout-map-image" src="' + options.maps[x].src + '" />');
+					if (typeof(options.maps[x]) == 'object') {
+						map.append('<div id="roundabout-map-' + x + '"></div>');
+						var curmap = $(map.children("#roundabout-map-" + x)[0]);
+						curmap.append('<img id="roundabout-map-image" src="' + options.maps[x].src + '" />');
 
-					// Add map panoramas
-					var panoramas = options.maps[x].panoramas;
-					for (var i = 0; i < panoramas.length; i++) {
-						// Add panoramas
-						curmap.append ('<div class="roundabout-map-panorama">&nbsp;</div>');
+						// Add map panoramas
+						var panoramas = options.maps[x].panoramas;
+						for (var i = 0; i < panoramas.length; i++) {
+							// Add panoramas
+							curmap.append ('<div class="roundabout-map-panorama">&nbsp;</div>');
+						}
+						curmap.children(".roundabout-map-panorama").each(function(i) {
+							$(this).css({
+								top: panoramas[i].y - parseInt(options.mapPanoramaSize/2),
+								left: panoramas[i].x - parseInt(options.mapPanoramaSize/2)
+							});
+
+							$(this).data("panorama", panoramas[i].id);
+
+							/**
+							* Event handler for mousedown on map panorama, navigates to the next panorama.
+							*
+							* @param {Object} e			This object points to the event object.
+							*/
+							$(this).mousedown(function(e) {
+								var obj = $($(this).parents(".roundabout-wrapper").get(0));
+								var options = $(obj).data("options");
+
+								// Hide all hotspots during anim
+								$(".roundabout-hotspot", obj).hide();
+								options.currentId = $(this).data("panorama");
+								obj.roundaboutGetPanorama();
+								obj.find(".roundabout-tile-" + options.otherTile).roundaboutSetImage();
+								options.animFrame = 0;
+								options.animAngle = 0;
+							});
+						});
+
+						// Add map hotspots
+						var hotspots = options.maps[x].hotspots;
+						for (var i = 0; i < hotspots.length; i++) {
+							// Add panoramas
+							curmap.append ('<div class="roundabout-map-hotspot">&nbsp;</div>');
+						}
+						curmap.children(".roundabout-map-hotspot").each(function(i) {
+							$(this).css({
+								top: hotspots[i].y,
+								left: hotspots[i].x,
+								width: hotspots[i].width,
+								height: hotspots[i].height
+							});
+
+							$(this).data("map", hotspots[i].target_map);
+
+							/**
+							* Event handler for mousedown on map hotspot, navigates to the next map.
+							*
+							* @param {Object} e			This object points to the event object.
+							*/
+							$(this).mousedown(function(e) {
+								var obj = $($(this).parents(".roundabout-wrapper").get(0));
+								var options = $(obj).data("options");
+
+								// Show the right map
+								obj.find(".roundabout-map-container").children().hide();
+								obj.find(".roundabout-map-container").children("#roundabout-map-" + $(this).data("map")).show();
+
+								// Check if compass should be visible
+								if (options.panoramas[options.currentId].map == $(this).data("map")) {
+									obj.find(".roundabout-map-compass").show();
+								} else {
+									obj.find(".roundabout-map-compass").hide();
+								}
+							});
+						});
 					}
-					curmap.children(".roundabout-map-panorama").each(function(i) {
-						$(this).css({
-							top: panoramas[i].y - parseInt(options.mapPanoramaSize/2),
-							left: panoramas[i].x - parseInt(options.mapPanoramaSize/2)
-						});
-
-						$(this).data("panorama", panoramas[i].id);
-
-						/**
-						* Event handler for mousedown on map panorama, navigates to the next panorama.
-						*
-						* @param {Object} e			This object points to the event object.
-						*/
-						$(this).mousedown(function(e) {
-							var obj = $($(this).parents(".roundabout-wrapper").get(0));
-							var options = $(obj).data("options");
-
-							// Hide all hotspots during anim
-							$(".roundabout-hotspot", obj).hide();
-							options.currentId = $(this).data("panorama");
-							obj.roundaboutGetPanorama();
-							obj.find(".roundabout-tile-" + options.otherTile).roundaboutSetImage();
-							options.animFrame = 0;
-							options.animAngle = 0;
-						});
-					});
-
-					// Add map hotspots
-					var hotspots = options.maps[x].hotspots;
-					for (var i = 0; i < hotspots.length; i++) {
-						// Add panoramas
-						curmap.append ('<div class="roundabout-map-hotspot">&nbsp;</div>');
-					}
-					curmap.children(".roundabout-map-hotspot").each(function(i) {
-						$(this).css({
-							top: hotspots[i].y,
-							left: hotspots[i].x,
-							width: hotspots[i].width,
-							height: hotspots[i].height
-						});
-
-						$(this).data("map", hotspots[i].target_map);
-
-						/**
-						* Event handler for mousedown on map hotspot, navigates to the next map.
-						*
-						* @param {Object} e			This object points to the event object.
-						*/
-						$(this).mousedown(function(e) {
-							var obj = $($(this).parents(".roundabout-wrapper").get(0));
-							var options = $(obj).data("options");
-
-							// Show the right map
-							obj.find(".roundabout-map-container").children().hide();
-							obj.find(".roundabout-map-container").children("#roundabout-map-" + $(this).data("map")).show();
-
-							// Check if compass should be visible
-							if (options.panoramas[options.currentId].map == $(this).data("map")) {
-								obj.find(".roundabout-map-compass").show();
-							} else {
-								obj.find(".roundabout-map-compass").hide();
-							}
-						});
-					});
 				}
 			}
 
